%define oname	getfem

%define major	3
%define libname	%mklibname %{oname} %{major}
%define devname %mklibname %{oname} -d

# No openmpi on 32bits with openmpi 5 in Mageia 10+
%ifarch %{ix86} %{arm32}
%bcond_with mpi
%else
%bcond_without mpi
%endif

%define gittag	4ed33482ba6f2a6e98083a8d0b0ad8860b587f4e
%define gitdate	20240910
%define rel	3

Name:		getfem++
Summary:	Generic and efficient C++ library for finite element methods
Version:	5.4.2
Release:	%mkrel %{rel}.git%{gitdate}
License:	LGPLv2+
Group:		System/Libraries
URL:		https://getfem.org/
# Source0:	https://download-mirror.savannah.gnu.org/releases/getfem/stable/%%{oname}-%%{version}.tar.gz
Source0:    	https://git.savannah.nongnu.org/cgit/getfem.git/snapshot/getfem-%{gittag}.tar.gz
BuildRequires:	blas-devel
BuildRequires:	lapack-devel
BuildRequires:	metis-devel
BuildRequires:	cmake(superlu)
BuildRequires:	pkgconfig(muparser)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(qhull)
BuildRequires:	python3dist(scipy)
%if %{with mpi}
BuildRequires:	python3dist(mpi4py)
%endif
BuildRequires:	python3-numpy-devel

%description
The Getfem++ project focuses on the development of a generic and efficient
C++ library for finite element methods. The goal is to provide a library
allowing the computation of any elementary matrix (even for mixed finite
element methods) on the largest class of methods and elements, and for
arbitrary dimension (i.e. not only 2D and 3D problems).

%package -n %{devname}
Summary:	Development files and headers for %{name}
Group:		Development/C++
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}
Provides:	gmm-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Recommends:	%{oname}-examples = %{version}-%{release}

%description -n %{devname}
This package contains the development files and headers for %{name}.

%files -n %{devname}
%{_bindir}/getfem-config
%{_includedir}/gmm/
%{_includedir}/getfem/
%{_libdir}/libgetfem.so

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries

%description -n %{libname}
The Getfem++ project focuses on the development of a generic and efficient
C++ library for finite element methods. The goal is to provide a library
allowing the computation of any elementary matrix (even for mixed finite
element methods) on the largest class of methods and elements, and for
arbitrary dimension (i.e. not only 2D and 3D problems).

%files -n %{libname}
%doc README
%{_libdir}/libgetfem.so.%{major}{,.*}

%package -n python3-getfem
Group:		Development/Python
Summary:	Python 3 binding for %{name}
%if %{with mpi}
Requires:	python3dist(mpi4py)
%endif
Requires:	python3dist(numpy)
Requires:	python3dist(scipy)

Provides:	python-getfem = %{version}-%{release}

%description -n python3-getfem
Python 3 binding for %{name}.

%files -n python3-getfem
%ifarch x86_64 aarch64
%dir %{python3_sitearch}/getfem
%endif
%dir %{python3_sitelib}/getfem
%{python3_sitearch}/getfem/_getfem*.so
%{python3_sitelib}/getfem/__init__.*
%{python3_sitelib}/getfem/getfem.py*
%{python3_sitelib}/getfem/__pycache__/

%package -n %{oname}-examples
Summary:	Examples for %{name}
Group:		Development/C++
BuildArch:	noarch

%description -n %{oname}-examples
This package contains some examples for %{name}.

%files -n %{oname}-examples
%{_datadir}/getfem_toolbox/

#--------------------------------------------------------------------

%prep
%if %{defined gittag}
%autosetup -p1 -n getfem-%{gittag}
%else
%autosetup -p1 -n getfem-%{version}
%endif

%build
autoreconf -vfi
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
	--enable-metis \
	--enable-python \
	--enable-shared \
	--disable-dependency-tracking \
	--disable-static \
	--disable-scilab \
 	--disable-mumps \
 	--enable-shared  \
	--with-matlab-toolbox-dir=%{_datadir}/getfem_toolbox
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

# Hack around
install -pm 0755 interface/src/python/_getfem*.so %{buildroot}%{python3_sitearch}/getfem/


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 5.4.2-3.git20240910.mga10
+ Revision: 2242858
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 wally <wally> 5.4.2-2.git20240910.mga10
+ Revision: 2160367
- rebuild for python3.13

* Tue Sep 10 2024 daviddavid <daviddavid> 5.4.2-1.git20240910.mga10
+ Revision: 2094921
- update to latest git snapshot as of 20240910 (second attempt to fix build with superlu 7.0.0)
- update to latest git snapshot as of 20240909 (attempt to fix build with superlu 7.0.0)
- rebuild for new superlu 7.0.0

* Wed Aug 28 2024 papoteur <papoteur> 5.4.2-1.git20240510.mga10
+ Revision: 2092084
- new version 5.4.2
- use git tag snapshot
- remove boost, no more used

* Fri Mar 15 2024 daviddavid <daviddavid> 5.3-8.mga10
+ Revision: 2049963
- disable mpi support on 32bits

* Wed Dec 20 2023 daviddavid <daviddavid> 5.3-7.mga10
+ Revision: 2020170
- rebuild for py3.12

* Sun May 21 2023 daviddavid <daviddavid> 5.3-6.mga9
+ Revision: 1957649
- provides also gmm-devel from devel sub-pkg

* Mon Apr 04 2022 umeabot <umeabot> 5.3-5.mga9
+ Revision: 1843531
- Mageia 9 Mass Rebuild
+ tv <tv>
- Rebuild for python-3.10

* Mon Mar 22 2021 daviddavid <daviddavid> 5.3-3.mga9
+ Revision: 1707859
- rebuild for python 3.9

* Tue Jun 23 2020 daviddavid <daviddavid> 5.3-2.mga8
+ Revision: 1598649
- rebuild for new qhull 2020.1

* Tue Feb 25 2020 daviddavid <daviddavid> 5.3-1.mga8
+ Revision: 1550212
- new version: 5.3
- port to python3
- drop python2 support
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 5.2-3.mga7
+ Revision: 1297867
- Mageia 7 Mass Rebuild

* Sat May 05 2018 daviddavid <daviddavid> 5.2-2.mga7
+ Revision: 1226377
- use new python provides
- build with --disable-dependency-tracking option

* Fri Feb 09 2018 daviddavid <daviddavid> 5.2-1.mga7
+ Revision: 1199913
- new version: 5.2
- now libmajor is 5
- update URL and Source URL
- remove no more needed patches
- do not package static libraries
- rename python-getfem to python2-getfem
- fix getfem_toolbox folder path

* Sun Feb 14 2016 umeabot <umeabot> 4.2-12.mga6
+ Revision: 960276
- Mageia 6 Mass Rebuild

* Mon Aug 31 2015 cjw <cjw> 4.2-11.mga6
+ Revision: 871419
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 4.2-10.mga5
+ Revision: 748687
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.2-9.mga5
+ Revision: 726318
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 4.2-8.mga5
+ Revision: 679547
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Jun 28 2014 wally <wally> 4.2-7.mga5
+ Revision: 640846
- enable shared build
- add lib and devel pkgs
- split out some examples
- add patches to fix build

* Sat May 31 2014 pterjan <pterjan> 4.2-6.mga5
+ Revision: 628216
- Rebuild for new Python

* Sat Oct 19 2013 umeabot <umeabot> 4.2-5.mga4
+ Revision: 529452
- Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 4.2-4.mga4
+ Revision: 451859
- br python
- rebuild for new boost

* Sat Jan 12 2013 umeabot <umeabot> 4.2-3.mga3
+ Revision: 351488
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 fwang <fwang> 4.2-2.mga3
+ Revision: 333778
- bump rel
- update file list
- update file list
- build shared libs
- add more br
- fix str fmt
- new version 4.2

* Fri May 06 2011 ahmad <ahmad> 4.0.0-4.mga1
+ Revision: 95279
- Revert the deleting of .la files

* Thu May 05 2011 ahmad <ahmad> 4.0.0-3.mga1
+ Revision: 95210
- Don't ship .la files

* Sat Jan 22 2011 ahmad <ahmad> 4.0.0-2.mga1
+ Revision: 33248
- imported package getfem++


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 4.0.0-2mdv2011.0
+ Revision: 605447
- rebuild

* Sat Feb 13 2010 Funda Wang <fwang@mandriva.org> 4.0.0-1mdv2010.1
+ Revision: 505336
- New version 4.0.0

* Wed Apr 08 2009 Funda Wang <fwang@mandriva.org> 3.1-1mdv2009.1
+ Revision: 365112
- BR boost
- New version 3.1

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

* Fri Apr 18 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 3.0.3-1mdv2009.0
+ Revision: 195695
- import getfem++


